@@ -13,7 +13,7 @@ rabbyt.init_display((640, 480))
 # Creating a sprite is easy.  Just give it an image filename.
 car = rabbyt.Sprite("car.png")
 
-while True:
+while not pygame.event.peek(pygame.QUIT):
     rabbyt.clear((1,1,1))
 
     car.render()
