@@ -19,7 +19,7 @@ sprites[2].y = extend("repeat")
 # Reverse is like repeat, only every other time it moves from end to start.
 sprites[3].y = extend("reverse")
 
-while True:
+while not pygame.event.peek(pygame.QUIT):
     rabbyt.clear()
     rabbyt.set_time(pygame.time.get_ticks())
 
