@@ -30,7 +30,7 @@ print "Drawing 2400 sprites..."
 
 c = pygame.time.Clock()
 last_fps = 0
-while True:
+while not pygame.event.peek(pygame.QUIT):
     c.tick()
     if pygame.time.get_ticks() - last_fps > 1000:
         print "FPS: ", c.get_fps()
