@@ -14,7 +14,7 @@ alphabet = set(hello_earthling)
 font = Font(pygame.font.Font(pygame.font.get_default_font(), 20),
                 alphabet=alphabet)
 sprite = FontSprite(font, hello_earthling)
-sprite.rot = rabbyt.lerp(0, 360, dt=6000, extend="repeat")
+sprite.rot = 20
 sprite.x = 100
 sprite.rgb = 0,1,1
 
