@@ -22,7 +22,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """)
 
 __author__ = "Matthew Marshall <matthew@matthewmarshall.org>"
-__version__ = "0.0.5"
+__version__ = "0.6"
 
 import heapq
 import os.path
@@ -30,6 +30,7 @@ import os.path
 from rabbyt._rabbyt import *
 from rabbyt.sprites import *
 from rabbyt.anims import *
+import rabbyt.physics, rabbyt.collisions
 
 extend_types = dict(constant=1, extrapolate=2, repeat=3, reverse=4)
 
@@ -48,37 +49,45 @@ def _handle_time_args(startt, endt, dt):
 
 def lerp(start, end, startt=None, endt=None, dt=None, extend="constant"):
     """
-    lerp(start, end, [startt,] [endt,] [dt,] [extend])
+    ``lerp(start, end, [startt,] [endt,] [dt,] [extend])``
 
-    Linearly interpolates between start and end as time moves from start to
-    endt.
+    Linearly interpolates between ``start`` and ``end`` as time moves from
+    ``startt`` to ``endt``.
 
-    startt is the time to start.  It defaults to rabbyt.get_time().
+    ``startt`` is the time to start.  It defaults to ``rabbyt.get_time()``.
 
-    To specify the ending time, use either endt, which is the absolute time,
-    or dt, which is relative from startt.
+    To specify the ending time, use either ``endt``, which is the absolute
+    time, or ``dt``, which is relative from ``startt``.
 
     For example, all of the following are equivalent:
 
-        lerp(0, 1, rabbyt.get_time(), rabbyt.get_time()+1000)
-        lerp(0, 1, rabbyt.get_time(), dt=1000)
-        lerp(0, 1, dt=1000)
+        .. sourcecode:: python
 
-    extend is a string defining what to do before startt and after endt.
-    Possible values are "constant", "extrapolate", "repeat", "reverse".  The
-    default is "constant".  Check out the extend_modes.py example for more info.
+            lerp(0, 1, rabbyt.get_time(), rabbyt.get_time()+1000)
+            lerp(0, 1, rabbyt.get_time(), dt=1000)
+            lerp(0, 1, dt=1000)
 
-    start and end can either be numbers, or tuples of numbers.  If they are
-    tuples, a tuple of anims will be returned.  For example, this line::
+    ``extend`` is a string defining what to do before ``startt`` and after
+    ``endt``. Possible values are "constant", "extrapolate", "repeat",
+    "reverse".  The default is "constant".  Check out the extend_modes.py
+    example for more info.
 
-        sprite.rgba = lerp((0,1,0,.5), (1,0,1,1), dt=1000)
+    ``start`` and ``end`` can either be numbers, or tuples of numbers.  If
+    they are tuples, a tuple of anims will be returned.  For example, this
+    line:
 
-    is equivalent to this::
+        .. sourcecode:: python
 
-        sprite.red   = lerp(0, 1, dt=1000)
-        sprite.green = lerp(1, 0, dt=1000)
-        sprite.blue  = lerp(0, 1, dt=1000)
-        sprite.alpha = lerp(.5,1, dt=1000)
+            sprite.rgba = lerp((0,1,0,.5), (1,0,1,1), dt=1000)
+
+    is equivalent to this:
+
+        .. sourcecode:: python
+
+            sprite.red   = lerp(0, 1, dt=1000)
+            sprite.green = lerp(1, 0, dt=1000)
+            sprite.blue  = lerp(0, 1, dt=1000)
+            sprite.alpha = lerp(.5,1, dt=1000)
 
     """
     extend = extend_types[extend]
@@ -95,18 +104,18 @@ def lerp(start, end, startt=None, endt=None, dt=None, extend="constant"):
 
 def wrap(bounds, parent, static=True):
     """
-    wrap(bounds, parent, static=True) -> AnimWrap | tuple of AnimWraps
+    ``wrap(bounds, parent, static=True) -> AnimWrap or tuple of AnimWraps``
 
-    Wraps a parent Anim to fit within bounds.  bounds should be an object that
-    supports item access for at least bounds[0] and bounds[1].  (A list or
-    tuple with a length of 2 would work great.)
+    Wraps a parent ``Anim`` to fit within ``bounds``.  ``bounds`` should be an
+    object that supports item access for at least ``bounds[0]`` and
+    ``bounds[1]``.  (A list or tuple with a length of 2 would work great.)
 
-    If static is True, bounds is only read once and stored in C variables for
-    fast access. This is much faster, but doesn't work if bounds is
-    an object you wish to mutate.
+    If ``static`` is ``True``, ``bounds`` is only read once and stored in C
+    variables for fast access. This is much faster, but doesn't work if
+    ``bounds`` is an object you wish to mutate.
 
-    If parent is a iterable, a tuple of anims will be returned instead
-    of a single one.  (This is similar to lerp.)
+    If ``parent`` is a iterable, a tuple of anims will be returned instead
+    of a single one.  (This is similar to ``lerp()``.)
     """
     try:
         iter(parent)
@@ -117,13 +126,15 @@ def wrap(bounds, parent, static=True):
 
 def bezier3(p0, p1, p2, p3, startt=None, endt=None, dt=None, extend="constant"):
     """
-    bezier3(p0, p1, p2, p3, [startt,] [endt,] [dt,] [extend])
+    ``bezier3(p0, p1, p2, p3, [startt,] [endt,] [dt,] [extend])``
 
-    Interpolates along a cubic bezier curve as defined by p0, p1, p2, and p3.
+    Interpolates along a cubic bezier curve as defined by ``p0``, ``p1``,
+    ``p2``, and ``p3``.
 
-    startt, endt, dt, and extend work as in lerp().
+    ``startt``, ``endt``, ``dt``, and ``extend`` work as in ``lerp()``.
 
-    p0, p1, p2, and p3 can be tuples, but they must all be the same length.
+    ``p0``, ``p1``, ``p2``, and ``p3`` can be tuples, but they must all be the
+    same length.
     """
     extend = extend_types[extend]
     startt, endt = _handle_time_args(startt, endt, dt)
@@ -139,6 +150,8 @@ def bezier3(p0, p1, p2, p3, startt=None, endt=None, dt=None, extend="constant"):
 
 class Scheduler(object):
     """
+    ``Scheduler()``
+
     Scheduler provides... (wait for it...)  scheduling!
 
     You may create your own scheduler instances, or use the default
@@ -149,20 +162,20 @@ class Scheduler(object):
 
     def add(self, time, callback):
         """
-        add(time, callback)
+        ``add(time, callback)``
 
-        Schedules a callback to be called at a given time.
+        Schedules a ``callback`` to be called at a given ``time``.
         """
         heapq.heappush(self.heap, (time, callback))
 
     def pump(self, time=None):
         """
-        pump([time])
+        ``pump([time])``
 
-        Calls all callbacks that have been scheduled for before 'time'
+        Calls all callbacks that have been scheduled for before ``time``.
 
-        If 'time' is not given, the value returned by rabbyt.get_time() will be
-        used.
+        If ``time`` is not given, the value returned by ``rabbyt.get_time()``
+        will be used.
         """
         if time is None:
             time = get_time()
@@ -199,13 +212,14 @@ data_directory = ""
 
 def pygame_load_texture(filename, filter=True, mipmap=True):
     """
-    pygame_load_texture(filename, filter=True, mipmap=True) -> texture_id, size
+    ``pygame_load_texture(filename, filter=True, mipmap=True) -> texture_id,
+    size``
 
     Reads an image from a file and loads it as a texture.  Pygame is used for
     reading the image.
 
-    If filename is a relative path, the working directory is searched first,
-    then rabbyt.data_directory is searched for the file.
+    If ``filename`` is a relative path, the working directory is searched
+    first, then ``rabbyt.data_directory`` is searched for the file.
     """
     if filename not in _texture_cache:
         import pygame
@@ -218,3 +232,12 @@ def pygame_load_texture(filename, filter=True, mipmap=True):
                 filter, mipmap), size
     return _texture_cache[filename]
 set_load_texture_file_hook(pygame_load_texture)
+
+__all__ = __docs_all__ = ('anims collisions fonts sprites physics vertexarrays '
+'Scheduler '
+'lerp wrap bezier3 '
+'init_display set_viewport set_default_attribs set_gl_color clear '
+'get_gl_vendor '
+'render_unsorted '
+'load_texture update_texture unload_texture pygame_load_texture '
+'set_load_texture_file_hook ').split()
\ No newline at end of file
