@@ -1,7 +1,6 @@
 from __future__ import division
 
 """
-rabbyt.fonts
 """
 
 __credits__ = (
@@ -48,25 +47,22 @@ def next_power_of_2(v):
 
 class Font(object):
     """
-    Font
+    ``Font(pygame_font, [alphabet])``
 
     Holds the information for drawing a font.
 
-    To actually draw a font you need to use a FontSprite.
+    ``pygame_font`` should be a ``pygame.font.Font`` instace.
+
+    ``alphabet`` is a string containing all of the characters that should
+    be loaded into video memory.  It defaults to
+    ``rabbyt.fonts.default_alphabet`` which includes numbers, symbols, and
+    letters used in the English language.
+
+    To actually draw a font you need to use a ``FontSprite``.
 
     The characters will be rendered onto an OpenGL texture.
     """
     def __init__(self, pygame_font, alphabet=default_alphabet):
-        """
-        Font(pygame_font, [alphabet])
-
-        pygame_font should be a pygame.font.Font instace.
-
-        alphabet is a string containing all of the characters that should be
-        loaded into video memory.  It defaults to rabbyt.fonts.default_alphabet
-        which includes numbers, symbols, and letters used in the English
-        language.
-        """
         self.pygame_font = pygame_font
         self.alphabet = alphabet
         widest = max(self.pygame_font.size(char)[0]+1 for char in alphabet)
@@ -109,18 +105,18 @@ class Font(object):
 
     def get_char_tex_shape(self, char):
         """
-        get_char_tex_shape(char)
+        ``get_char_tex_shape(char)``
 
-        Returns the texture shape of the given character in the form of (left,
-        top, right, bottom).
+        Returns the texture shape of the given character in the form of
+        ``(left, top, right, bottom)``.
 
-        KeyError is raised if char is not in the font's alphabet.
+        ``KeyError`` is raised if ``char`` is not in the font's ``alphabet``.
         """
         return self.coords[char]
 
     def get_char_width(self, char):
         """
-        get_char_width(char)
+        ``get_char_width(char)``
 
         Returns the width in pixels of the given character.
         """
@@ -132,22 +128,19 @@ class Font(object):
 
 class FontSprite(BaseSprite):
     """
-    FontSprite
+    ``FontSprite(font, text, ...)``
 
-    A sprite that displays text from a Font.
+    A sprite that displays text from a ``Font``.
 
-    This inherits from BaseSprite, so you can use all of the transformation and
-    color properties.
+    ``font`` should be a ``rabbyt.fonts.Font`` instance to be used.
+
+    ``text`` is the string to be displayed!  (It can be changed later with
+    the text property.)
+
+    This inherits from ``BaseSprite``, so you can use all of the
+    transformation and color properties.
     """
     def __init__(self, font, text, **kwargs):
-        """
-        FontSprite(font, text, ...)
-
-        font should be a rabbyt.fonts.Font instance to be used.
-
-        text is the string to be displayed!  (It can be changed later with the
-        text property.)
-        """
         BaseSprite.__init__(self, **kwargs)
         self.font = font
         self.texture_id = font.texture_id
@@ -179,3 +172,4 @@ class FontSprite(BaseSprite):
         rabbyt.set_gl_color(self.rgba)
         self.va.render()
 
+__docs_all__ = ('Font', 'FontSprite')
